@@ -1,2 +1,3 @@
+import freenit.api.user
+
 from .router import api
-from .user import UserDB
